@@ -94,9 +94,9 @@ import numpy as np
 import scipy.special
 from numba import jit
 from ..normal_form_game import Player, NormalFormGame
-from ...util import check_random_state
-from ...gridtools import simplex_grid
-from ...graph_tools import random_tournament_graph
+from ...util import check_random_state, rng_integers
+from ..._gridtools import simplex_grid
+from ..._graph_tools import random_tournament_graph
 from ...util.combinatorics import next_k_array, k_array_rank_jit
 
 __all__ = [
@@ -129,11 +129,11 @@ def blotto_game(h, t, rho, mu=0, random_state=None):
         [-1, 1].
     mu : scalar(float), optional(default=0)
         Mean of the players' values of each hill.
-    random_state : int or np.random.RandomState, optional
-        Random seed (integer) or np.random.RandomState instance to set
-        the initial state of the random number generator for
-        reproducibility. If None, a randomly initialized RandomState is
-        used.
+    random_state : int or np.random.RandomState/Generator, optional
+        Random seed (integer) or np.random.RandomState or Generator
+        instance to set the initial state of the random number generator
+        for reproducibility. If None, a randomly initialized RandomState
+        is used.
 
     Returns
     -------
@@ -225,11 +225,11 @@ def ranking_game(n, steps=10, random_state=None):
         the costs are multiples of `1/(n*steps)`, where the cost of
         effort level `0` is 0, and the maximum possible cost of effort
         level `n-1` is less than or equal to 1.
-    random_state : int or np.random.RandomState, optional
-        Random seed (integer) or np.random.RandomState instance to set
-        the initial state of the random number generator for
-        reproducibility. If None, a randomly initialized RandomState is
-        used.
+    random_state : int or np.random.RandomState/Generator, optional
+        Random seed (integer) or np.random.RandomState or Generator
+        instance to set the initial state of the random number generator
+        for reproducibility. If None, a randomly initialized RandomState
+        is used.
 
     Returns
     -------
@@ -255,11 +255,11 @@ def ranking_game(n, steps=10, random_state=None):
     payoff_arrays = tuple(np.empty((n, n)) for i in range(2))
     random_state = check_random_state(random_state)
 
-    scores = random_state.randint(1, steps+1, size=(2, n))
+    scores = rng_integers(random_state, 1, steps+1, size=(2, n))
     scores.cumsum(axis=1, out=scores)
 
     costs = np.empty((2, n-1))
-    costs[:] = random_state.randint(1, steps+1, size=(2, n-1))
+    costs[:] = rng_integers(random_state, 1, steps+1, size=(2, n-1))
     costs.cumsum(axis=1, out=costs)
     costs[:] /= (n * steps)
 
@@ -415,11 +415,11 @@ def tournament_game(n, k, random_state=None):
         Number of nodes in the tournament graph.
     k : scalar(int)
         Size of subsets of nodes in the tournament graph.
-    random_state : int or np.random.RandomState, optional
-        Random seed (integer) or np.random.RandomState instance to set
-        the initial state of the random number generator for
-        reproducibility. If None, a randomly initialized RandomState is
-        used.
+    random_state : int or np.random.RandomState/Generator, optional
+        Random seed (integer) or np.random.RandomState or Generator
+        instance to set the initial state of the random number generator
+        for reproducibility. If None, a randomly initialized RandomState
+        is used.
 
     Returns
     -------
@@ -548,11 +548,11 @@ def unit_vector_game(n, avoid_pure_nash=False, random_state=None):
         If True, player 0's payoffs will be placed in order to avoid
         pure Nash equilibria. (If necessary, the payoffs for player 1
         are redrawn so as not to have a dominant action.)
-    random_state : int or np.random.RandomState, optional
-        Random seed (integer) or np.random.RandomState instance to set
-        the initial state of the random number generator for
-        reproducibility. If None, a randomly initialized RandomState is
-        used.
+    random_state : int or np.random.RandomState/Generator, optional
+        Random seed (integer) or np.random.RandomState or Generator
+        instance to set the initial state of the random number generator
+        for reproducibility. If None, a randomly initialized RandomState
+        is used.
 
     Returns
     -------
@@ -590,10 +590,10 @@ def unit_vector_game(n, avoid_pure_nash=False, random_state=None):
 
     """
     random_state = check_random_state(random_state)
-    payoff_arrays = (np.zeros((n, n)), random_state.random_sample((n, n)))
+    payoff_arrays = (np.zeros((n, n)), random_state.random((n, n)))
 
     if not avoid_pure_nash:
-        ones_ind = random_state.randint(n, size=n)
+        ones_ind = rng_integers(random_state, n, size=n)
         payoff_arrays[0][ones_ind, np.arange(n)] = 1
     else:
         if n == 1:
@@ -603,15 +603,15 @@ def unit_vector_game(n, avoid_pure_nash=False, random_state=None):
         nums_suboptimal = is_suboptimal.sum(axis=1)
 
         while (nums_suboptimal==0).any():
-            payoff_arrays[1][:] = random_state.random_sample((n, n))
+            payoff_arrays[1][:] = random_state.random((n, n))
             payoff_arrays[1].max(axis=0, out=maxes)
             np.less(payoff_arrays[1], maxes, out=is_suboptimal)
             is_suboptimal.sum(axis=1, out=nums_suboptimal)
 
         for i in range(n):
-            one_ind = random_state.randint(n)
+            one_ind = rng_integers(random_state, n)
             while not is_suboptimal[i, one_ind]:
-                one_ind = random_state.randint(n)
+                one_ind = rng_integers(random_state, n)
             payoff_arrays[0][one_ind, i] = 1
 
     g = NormalFormGame(
